@@ -19,14 +19,7 @@
 #
 
 """
-Perform various checks on gettext files:
-* compilation (with command `msgfmt -c`)
-* for each translation:
-  * number of lines in translated strings
-  * whitespace at beginning/end of strings
-  * trailing whitespace at end of lines inside strings
-  * punctuation at end of strings
-  * spelling
+Perform various checks on gettext files.
 """
 
 from . import msgcheck
