@@ -39,7 +39,7 @@ import sys
 from . po import PoCheck
 
 
-__version__ = '2.7'
+__version__ = '2.8'
 
 
 def msgcheck_version():
@@ -134,8 +134,12 @@ def main():
             total_errors += len(reports)
             if not args.quiet:
                 if args.only_misspelled:
-                    print('\n'.join([report.message for report in reports
-                                     if report.idmsg.startswith('spelling-')]))
+                    words = []
+                    for report in reports:
+                        for word in report.get_misspelled_words():
+                            words.append(word)
+                    print('\n'.join(sorted(set(words),
+                                           key=lambda s: s.lower())))
                 else:
                     print('\n'.join([str(report) for report in reports]))
         else:
